#include <iostream>
#include <map>
#include <cassert>
#include <vector>
#include <string>
#include <algorithm>
#include <cstring>
#include <cstdio>

using namespace std;

typedef long long ll;

const int kMaxC = 26;

struct TreeNode {
	int length, depth;
	TreeNode * suffixLink;
	TreeNode * jumps[kMaxC];
	
	TreeNode() {}
	
	inline bool hasNext(char letter) const {
		return jumps[letter - 'a'] != 0;
	}
	
	inline TreeNode * getNext(char letter) {
		return jumps[letter - 'a'];
	}
	
	inline void setNext(char letter, TreeNode * node) {
		jumps[letter - 'a'] = node;
	}
	
	inline void clear() {
		suffixLink = 0;
		depth = 0;
		memset(jumps, 0, sizeof(jumps));
	}
};

const int kMaxNodes = 600000 + 10;
TreeNode nodes[kMaxNodes];
int nodesAllocated;


char firstString[kMaxNodes];
char secondString[kMaxNodes];

TreeNode * newTreeNode(int length) {
	nodes[nodesAllocated].clear();
	nodes[nodesAllocated].length = length;
	return &nodes[nodesAllocated++];
}

struct Tree {
	char * letters;
	int * resultArray;
	TreeNode * oddRoot;
	TreeNode * evenRoot;
	TreeNode * lastLink;
	
	Tree(char * letters, int * resultArray) : letters(letters), resultArray(resultArray)
	{
		oddRoot = newTreeNode(-1);
		evenRoot = newTreeNode(0);
		oddRoot->suffixLink = oddRoot;
		evenRoot->suffixLink = oddRoot;
		lastLink = evenRoot;
	}
	
	inline bool canExtend(TreeNode * node, int position) {
		int mirrorPosition = position - node->length - 1;
		return (mirrorPosition >= 0 && letters[mirrorPosition] == letters[position]);
	}
	
	inline bool insertLetter(int position) {
		char letter = letters[position];
		TreeNode * currentLink = lastLink;
		
		while(!canExtend(currentLink, position))
			currentLink = currentLink->suffixLink;
			
		if(currentLink->hasNext(letter)) {
			lastLink = currentLink->getNext(letter);
			return false;
		}
		
		TreeNode * newNode = newTreeNode(currentLink->length + 2);
		
		currentLink->setNext(letter, newNode);
		lastLink = newNode;
		
		if(newNode->length == 1) {
			newNode->suffixLink = evenRoot;
			return true;
		}
		
		TreeNode * newSuffixLink = currentLink->suffixLink;
		
		while(!canExtend(newSuffixLink, position))
			newSuffixLink = newSuffixLink->suffixLink;
		
		assert(newSuffixLink->hasNext(letter));
		newNode->suffixLink = newSuffixLink->getNext(letter);
		
		return true;
	}
	
	void build() {
		int n = strlen(letters);
		for(int i = 0; i < n; i++) {
			insertLetter(i);
			lastLink->depth = lastLink->suffixLink->depth + 1;
			resultArray[i] = lastLink->depth;
		}
	}
};

int firstArray[kMaxNodes], secondArray[kMaxNodes];

void solve() {
	nodesAllocated = 0;
	gets(firstString);
	int n = strlen(firstString);
	for(int i = 0; i < n; i++)
		secondString[n - i - 1] = firstString[i];
	Tree firstTree(firstString, firstArray);
	firstTree.build();
	Tree secondTree(secondString, secondArray);
	secondTree.build();
	ll result = 0;
	for(int i = 0; i < n - 1; i++) {
		result += ll(firstArray[i]) * secondArray[n - i - 2];
	}
	printf("%lld\n", result);
}

int main() {
	solve();
	return 0;
}