#include <iostream>
#include <map>
#include <cassert>
#include <vector>
#include <string>
#include <algorithm>
#include <cstring>

using namespace std;

typedef long long ll;

const int kMaxC = 26;

struct TreeNode {
	int length;
	TreeNode * suffixLink;
	TreeNode * jumps[kMaxC];
	ll was;
	bool used;
	
	TreeNode() {}
	
	bool hasNext(char letter) const {
		return jumps[letter - 'a'] != 0;
	}
	
	TreeNode * getNext(char letter) {
		return jumps[letter - 'a'];
	}
	
	void setNext(char letter, TreeNode * node) {
		jumps[letter - 'a'] = node;
	}
	
	void clear() {
		suffixLink = 0;
		was = 0;
		used = false;
		memset(jumps, 0, sizeof(jumps));
	}
};

const int kMaxNodes = 400000 + 10;
TreeNode nodes[kMaxNodes];
int nodesAllocated;


char firstString[kMaxNodes];
char secondString[kMaxNodes];

TreeNode * newTreeNode(int length) {
	nodes[nodesAllocated].clear();
	nodes[nodesAllocated].length = length;
	return &nodes[nodesAllocated++];
}

struct Tree {
	char * letters;
	TreeNode * oddRoot;
	TreeNode * evenRoot;
	TreeNode * lastLink;
	
	Tree(char * letters) : letters(letters)
	{
		oddRoot = newTreeNode(-1);
		evenRoot = newTreeNode(0);
		oddRoot->suffixLink = oddRoot;
		evenRoot->suffixLink = oddRoot;
		lastLink = evenRoot;
	}
	
	bool canExtend(TreeNode * node, int position) {
		int mirrorPosition = position - node->length - 1;
		return (mirrorPosition >= 0 && letters[mirrorPosition] == letters[position]);
	}
	
	bool insertLetter(int position) {
		char letter = letters[position];
		TreeNode * currentLink = lastLink;
		
		while(!canExtend(currentLink, position))
			currentLink = currentLink->suffixLink;
			
		if(currentLink->hasNext(letter)) {
			lastLink = currentLink->getNext(letter);
			return false;
		}
		
		TreeNode * newNode = newTreeNode(currentLink->length + 2);
		
		currentLink->setNext(letter, newNode);
		lastLink = newNode;
		
		if(newNode->length == 1) {
			newNode->suffixLink = evenRoot;
			return true;
		}
		
		TreeNode * newSuffixLink = currentLink->suffixLink;
		
		while(!canExtend(newSuffixLink, position))
			newSuffixLink = newSuffixLink->suffixLink;
		
		assert(newSuffixLink->hasNext(letter));
		newNode->suffixLink = newSuffixLink->getNext(letter);
		
		return true;
	}
	
	void build() {
		int n = strlen(letters);
		for(int i = 0; i < n; i++) {
			insertLetter(i);
			lastLink->was += 1;
		}
	}
	
	typedef pair < int, TreeNode * > pair_t;
	
	void dfs(TreeNode * node, vector < pair_t > & top) {
		top.push_back(make_pair(node->length, node));
		for(char c = 'a'; c <= 'z'; c++) {
			TreeNode * v = node->getNext(c);
			if(v && !v->used)
				dfs(v, top);
		}
		node->suffixLink->was += node->was;
	}
	
	void getOcc() {
		vector < pair_t > top;
		dfs(oddRoot, top);
		if(!evenRoot->used)
			dfs(evenRoot, top);
	}
};

void dfsFinal(TreeNode * a, TreeNode * b, ll & x, ll & y, ll & z, bool isRoot) {
	if(!a && !b) return;
	if(!isRoot) {
		ll aCnt = (a ? a->was : 0);
		ll bCnt = (b ? b->was : 0);
		if(aCnt > bCnt)
			++x;
		else if(aCnt == bCnt)
			++y;
		else
			++z;
	}
	for(char c = 'a'; c <= 'z'; c++) {
		dfsFinal((!a ? 0 : a->getNext(c)), (!b ? 0 : b->getNext(c)), x, y, z, false);
	}
}

void solveOne() {
	nodesAllocated = 0;
	scanf("%s%s", firstString, secondString);
	Tree firstTree(firstString), secondTree(secondString);
	firstTree.build();
	secondTree.build();
	firstTree.getOcc();
	secondTree.getOcc();
	ll x = 0, y = 0, z = 0;
	dfsFinal(firstTree.oddRoot, secondTree.oddRoot, x, y, z, true);
	dfsFinal(firstTree.evenRoot, secondTree.evenRoot, x, y, z, true);
	printf("%lld %lld %lld", x, y, z);
}

int main() {
	int tests;
	scanf("%d", &tests);
	for(int test = 1; test <= tests; test++) {
		printf("Case #%d: ", test);
		solveOne();
		printf("\n");
	}
	return 0;
}