#include <iostream>
#include <map>
#include <cassert>
#include <vector>
#include <string>
#include <algorithm>
#include <cstring>

using namespace std;

typedef long long ll;

const int kMaxC = 26;

struct TreeNode {
	int length;
	TreeNode * suffixLink;
	TreeNode * jumps[kMaxC];
	ll was;
	
	TreeNode() {}
	
	inline bool hasNext(char letter) const {
		return jumps[letter - 'a'] != 0;
	}
	
	inline TreeNode * getNext(char letter) {
		return jumps[letter - 'a'];
	}
	
	inline void setNext(char letter, TreeNode * node) {
		jumps[letter - 'a'] = node;
	}
	
	inline void clear() {
		suffixLink = 0;
		was = 0;
		memset(jumps, 0, sizeof(jumps));
	}
};

const int kMaxNodes = 400000 + 10;
TreeNode nodes[kMaxNodes];
int nodesAllocated;


char firstString[kMaxNodes];
char secondString[kMaxNodes];

TreeNode * newTreeNode(int length) {
	nodes[nodesAllocated].clear();
	nodes[nodesAllocated].length = length;
	return &nodes[nodesAllocated++];
}

struct Tree {
	char * letters;
	TreeNode * oddRoot;
	TreeNode * evenRoot;
	TreeNode * lastLink;
	
	Tree(char * letters) : letters(letters)
	{
		oddRoot = newTreeNode(-1);
		evenRoot = newTreeNode(0);
		oddRoot->suffixLink = oddRoot;
		evenRoot->suffixLink = oddRoot;
		lastLink = evenRoot;
	}
	
	inline bool canExtend(TreeNode * node, int position) {
		int mirrorPosition = position - node->length - 1;
		return (mirrorPosition >= 0 && letters[mirrorPosition] == letters[position]);
	}
	
	inline bool insertLetter(int position) {
		char letter = letters[position];
		TreeNode * currentLink = lastLink;
		
		while(!canExtend(currentLink, position))
			currentLink = currentLink->suffixLink;
			
		if(currentLink->hasNext(letter)) {
			lastLink = currentLink->getNext(letter);
			return false;
		}
		
		TreeNode * newNode = newTreeNode(currentLink->length + 2);
		
		currentLink->setNext(letter, newNode);
		lastLink = newNode;
		
		if(newNode->length == 1) {
			newNode->suffixLink = evenRoot;
			return true;
		}
		
		TreeNode * newSuffixLink = currentLink->suffixLink;
		
		while(!canExtend(newSuffixLink, position))
			newSuffixLink = newSuffixLink->suffixLink;
		
		assert(newSuffixLink->hasNext(letter));
		newNode->suffixLink = newSuffixLink->getNext(letter);
		
		return true;
	}
	
	void build() {
		int n = strlen(letters);
		for(int i = 0; i < n; i++) {
			insertLetter(i);
			lastLink->was += 1;
		}
	}
	
	inline void dfs(TreeNode * node) {
		for(char c = 'a'; c <= 'z'; c++) {
			TreeNode * v = node->getNext(c);
			if(v)
				dfs(v);
		}
		node->suffixLink->was += node->was;
	}
	
	void getOcc() {
		dfs(oddRoot);
		dfs(evenRoot);
	}
};

ll x, y, z;

TreeNode * aStack[kMaxNodes];
TreeNode * bStack[kMaxNodes];

void dfsFinal(TreeNode * aInit, TreeNode * bInit) {
	int stackCursor = 0;
	aStack[stackCursor] = aInit;
	bStack[stackCursor] = bInit;
	++stackCursor;
	bool isRoot = true;
	while(stackCursor != 0) {
		--stackCursor;
		TreeNode * a = aStack[stackCursor];
		TreeNode * b = bStack[stackCursor];
		if(!isRoot) {
			ll aCnt = (a ? a->was : 0);
			ll bCnt = (b ? b->was : 0);
			if(aCnt > bCnt)
				++x;
			else if(aCnt == bCnt)
				++y;
			else
				++z;
		} else {
			isRoot = false;
		}
		for(char c = 'a'; c <= 'z'; c++) {
			TreeNode * u = (!a ? 0 : a->getNext(c));
			TreeNode * v = (!b ? 0 : b->getNext(c));
			if(u || v) {
				aStack[stackCursor] = u;
				bStack[stackCursor] = v;
				++stackCursor;
			}
		}
	}
}

void solveOne() {
	nodesAllocated = 0;
	gets(firstString);
	gets(secondString);
	Tree firstTree(firstString);
	firstTree.build();
	firstTree.getOcc();
	Tree secondTree(secondString);
	secondTree.build();
	secondTree.getOcc();
	x = 0, y = 0, z = 0;
	dfsFinal(firstTree.oddRoot, secondTree.oddRoot);
	dfsFinal(firstTree.evenRoot, secondTree.evenRoot);
	printf("%lld %lld %lld", x, y, z);
}

int main() {
	int tests;
	scanf("%d\n", &tests);
	for(int test = 1; test <= tests; test++) {
		printf("Case #%d: ", test);
		solveOne();
		printf("\n");
	}
	return 0;
}