#include <iostream>
#include <map>
#include <cassert>
#include <vector>
#include <string>
#include <algorithm>
#include <cstring>

using namespace std;

typedef long long ll;

const int kMaxC = 27;

const int kMaxNodes = 400000 + 10;

int nodesAllocated;

int length[kMaxNodes], suffixLink[kMaxNodes];
int jumps[kMaxNodes][kMaxC];
ll was[kMaxNodes];

char firstString[kMaxNodes];
char secondString[kMaxNodes];

int newTreeNode(int l) {
	length[nodesAllocated] = l;
	suffixLink[nodesAllocated] = 0;
	memset(jumps[nodesAllocated], 0, sizeof(jumps[nodesAllocated]));
	was[nodesAllocated] = 0;
	return nodesAllocated++;
}

inline bool hasNext(int n, char c) {
	return jumps[n][c - 'a'] != 0;
}

inline void setNext(int n, char c, int i) {
	jumps[n][c - 'a'] = i;
}

inline int getNext(int n, char c) {
	return jumps[n][c - 'a'];
}

struct Tree {
	char * letters;
	int oddRoot;
	int evenRoot;
	int lastLink;
	
	Tree(char * letters) : letters(letters)
	{
		oddRoot = newTreeNode(-1);
		evenRoot = newTreeNode(0);
		suffixLink[oddRoot] = oddRoot;
		suffixLink[evenRoot] = oddRoot;
		lastLink = evenRoot;
	}
	
	inline bool canExtend(int node, int position) {
		int mirrorPosition = position - length[node] - 1;
		return (mirrorPosition >= 0 && letters[mirrorPosition] == letters[position]);
	}
	
	inline void insertLetter(int position) {
		char letter = letters[position];
		int currentLink = lastLink;
		
		while(!canExtend(currentLink, position))
			currentLink = suffixLink[currentLink];
			
		if(hasNext(currentLink, letter)) {
			lastLink = getNext(currentLink, letter);
			return;
		}
		
		int newNode = newTreeNode(length[currentLink] + 2);
		
		setNext(currentLink, letter, newNode);
		lastLink = newNode;
		
		if(length[newNode] == 1) {
			suffixLink[newNode] = evenRoot;
			return;
		}
		
		int newSuffixLink = suffixLink[currentLink];
		
		while(!canExtend(newSuffixLink, position))
			newSuffixLink = suffixLink[newSuffixLink];
		
		suffixLink[newNode] = getNext(newSuffixLink, letter);
	}
	
	void build() {
		int n = strlen(letters);
		for(int i = 0; i < n; i++) {
			insertLetter(i);
			was[lastLink] += 1;
		}
	}
	
	inline void dfs(int node) {
		for(char c = 'a'; c <= 'z'; c++) {
			int v = getNext(node, c);
			if(v)
				dfs(v);
		}
		was[suffixLink[node]] += was[node];
	}
	
	void getOcc() {
		dfs(oddRoot);
		dfs(evenRoot);
	}
};

ll x, y, z;

void recalc(int a, int b, int s) {

			ll aCnt = (a ? was[a] : 0);
			ll bCnt = (b ? was[b] : 0);
			if(aCnt > bCnt)
				x += s;
			else if(aCnt == bCnt) {
				assert(a);
				y += s;
			} else
				z += s;
		}
	

void dfsFinal(int a, int b) {
		recalc(a, b, 1);
		for(char c = 'a'; c <= 'z' + 1; c++) {
			int u = (!a ? 0 : getNext(a, c));
			int v = (!b ? 0 : getNext(b, c));
			if(u || v) {
				dfsFinal(u, v);
			}
		}

}

void solveOne() {
	nodesAllocated = 1;
	gets(firstString);
	gets(secondString);
	Tree firstTree(firstString);
	firstTree.build();
	firstTree.getOcc();
	Tree secondTree(secondString);
	secondTree.build();
	secondTree.getOcc();
	x = 0, y = 0, z = 0;
	setNext(firstTree.oddRoot, 'z' + 1, firstTree.evenRoot);
	setNext(secondTree.oddRoot, 'z' + 1, secondTree.evenRoot);
	dfsFinal(firstTree.oddRoot, secondTree.oddRoot);
	recalc(firstTree.oddRoot, secondTree.oddRoot, -1);
	recalc(firstTree.evenRoot, secondTree.evenRoot, -1);
	
	printf("%lld %lld %lld", x, y, z);
}

int main() {
	int tests;
	scanf("%d\n", &tests);
	for(int test = 1; test <= tests; test++) {
		printf("Case #%d: ", test);
		solveOne();
		printf("\n");
	}
	return 0;
}