#include <iostream>
#include <string>
#include <vector>
#include <algorithm>
using namespace std;

const int kMaxN = 2e5 + 10;
const int kMaxC = 26;

struct Node
{
    int next[kMaxC];

    int amount;
    int suff_link;
    int len;

    Node()
    {
        for (int i = 0; i < kMaxC; ++i) {
            next[i] = 0;
        }
    }
};

struct PalindromicTree
{

    vector<Node> tree;
    int max_suff_id;
    int tree_size;

    int n;

    string s;

    PalindromicTree(const string& s) :
        s(s),
        n(s.length())
    {
        tree.resize(n + 3);
        Init();
    }

    void Init()
    {
        tree_size = 2;

        tree[1].amount = 0;
        tree[1].suff_link = 1;
        tree[1].len = -1;

        tree[2].amount = 0;
        tree[2].suff_link = 1;
        tree[2].len = 0;

        max_suff_id = 2;
    }

    bool AddLetter(int pos)
    {
        int letter = s[pos] - 'a';

        int cur_suff = max_suff_id;
        int cur_len = tree[cur_suff].len;

        while (true) {
            if (pos - cur_len - 1 >= 0 && s[pos - cur_len - 1] == s[pos]) {
                break;
            }

            cur_suff = tree[cur_suff].suff_link;
            cur_len = tree[cur_suff].len;
        }

        if (tree[cur_suff].next[letter]) {
            max_suff_id = tree[cur_suff].next[letter];
            ++tree[max_suff_id].amount;
            return false;
        }

        ++tree_size;
        tree[cur_suff].next[letter] = tree_size;
        tree[tree_size].len = cur_len + 2;

        max_suff_id = tree_size;
        tree[max_suff_id].amount = 1;

        if (cur_suff == 1) {
            tree[tree_size].suff_link = 2;
            return true;
        }

        while (true) {
            cur_suff = tree[cur_suff].suff_link;
            cur_len = tree[cur_suff].len;
            if (pos - cur_len - 1 >= 0 && s[pos - cur_len - 1] == s[pos]) {
                break;
            }
        }

        tree[tree_size].suff_link = tree[cur_suff].next[letter];

        return true;
    }

    void Recalc()
    {
        for (int i = tree_size; i >= 3; --i) {
            tree[tree[i].suff_link].amount += tree[i].amount;
        }
    }

};

void Calc(PalindromicTree& pt)
{
    for (int i = 0; i < pt.n; ++i) {
        pt.AddLetter(i);
    }
    pt.Recalc();
}

long long ans1, ans2, ans3;

void DFS(const PalindromicTree& pt1, const PalindromicTree& pt2,
            int pos1, int pos2)
{
    if (!pos1 && !pos2) {
        return ;
    } else if (!pos1) {
        if (pos2 != 1 && pos2 != 2) {
            ++ans3;
        }
        for (int c = 0; c < kMaxC; ++c) {
            DFS(pt1, pt2, pos1, pt2.tree[pos2].next[c]);
        }
    } else if (!pos2) {
        if (pos1 != 1 && pos1 != 2) {
            ++ans1;
        }
        for (int c = 0; c < kMaxC; ++c) {
            DFS(pt1, pt2, pt1.tree[pos1].next[c], pos2);
        }
    } else {
        if (pos1 != 1 && pos1 != 2) {
            int a = pt1.tree[pos1].amount;
            int b = pt2.tree[pos2].amount;

            if (a > b) {
                ++ans1;
            } else if (a == b) {
                ++ans2;
            } else {
                ++ans3;
            }
        }
        for (int c = 0; c < kMaxC; ++c) {
            DFS(pt1, pt2, pt1.tree[pos1].next[c], pt2.tree[pos2].next[c]);
        }
    }
}

int main()
{
    //freopen("input.txt", "r", stdin);
    ios_base::sync_with_stdio(false);


    int tests;
    cin >> tests;
    for (int test = 1; test <= tests; ++test) {
        string s1;
        string s2;
        cin >> s1 >> s2;

        PalindromicTree pt1(s1);
        PalindromicTree pt2(s2);

        Calc(pt1);
        Calc(pt2);

        ans1 = ans2 = ans3 = 0;

        DFS(pt1, pt2, 1, 1);
        DFS(pt1, pt2, 2, 2);

        cout << "Case #" << test << ": " << ans1 << " " << ans2 << " " << ans3 << endl;
    }

    return 0;
}
