#include <algorithm>
#include <cassert>
#include <cmath>
#include <complex>
#include <cstdio>
#include <cstring>
#include <iostream>
#include <map>
#include <set>
#include <string>
#include <sstream>
#include <vector>
using namespace std;

typedef pair<int, int> ii;
typedef vector<int> vi;
typedef vector<ii> vii;
typedef vector<vector<int> > vvi;
typedef long long ll;
template <class T> int size(const T& x) {return x.size();}

const double EPS = 1e-9;
const int INF = 2147483647;

#define MAXN 201000
#define SIGMA 26
#define BASE 'a'
struct state {
    int len, link, to[SIGMA], cnt;
};

struct palindromic_tree {
    int last, sz, n;
    char *s;
    state *st;
    palindromic_tree(char *_s, state *_st) : last(1), sz(2), n(0) {
        s = _s;
        st = _st;

        int maxn = strlen(s) + 100;
        memset(st, 0, maxn * sizeof(state));

        st[0].len = st[0].link = -1;
        st[1].len = st[1].link = 0;
    }
    int extend() {
        char c = s[n++];
        int p = last;
        while (n - st[p].len - 2 < 0 || c != s[n-st[p].len-2]) {
            p = st[p].link;
        }

        if (!st[p].to[c-BASE]) {
            int q = last = sz++;
            st[p].to[c-BASE] = q;
            st[q].len = st[p].len + 2;
            do {
                p = st[p].link;
            } while (p != -1 && (n < st[p].len + 2 || c != s[n-st[p].len-2]));

            if (p == -1) st[q].link = 1;
            else st[q].link = st[p].to[c-BASE];

            return 1;
        }

        last = st[p].to[c-BASE];
        return 0;
    }
};

vi *children = new vi[MAXN];
bool *visited = new bool[MAXN];

void cntz(const palindromic_tree &t, int at) {
    if (visited[at])
        return;

    visited[at] = true;

    //t.st[at].cnt = 1;
    for (int i = 0; i < size(children[at]); i++) {
        cntz(t, children[at][i]);
        t.st[at].cnt += t.st[children[at][i]].cnt;
    }
}

void outp(const palindromic_tree &t, int at, string s) {
    if (s != "") {
        cout << s << ": " << t.st[at].cnt << endl;
    }

    for (int i = 0; i < SIGMA; i++) {
        if (t.st[at].to[i]) {
            char c = static_cast<char>(BASE + i);
            outp(t, t.st[at].to[i], at == 0 ? s + c : string("") + c + s + c);
        }
    }
}

int cleft, csame, cright;

void doit(const palindromic_tree &t1, int at1, bool done1, const palindromic_tree &t2, int at2, bool done2) {

    //printf("%d %d, %d %d\n", at1, at2, done1, done2);

    if (done1 && done2)
        return;

    int cl = 0,
        cr = 0;

    if (!done1) cl = t1.st[at1].cnt;
    if (!done2) cr = t2.st[at2].cnt;

    if ((cl > 0 || cr > 0) && (at1 > 1 || at2 > 1)) {

        if (cl > cr) cleft++;
        else if (cl < cr) cright++;
        else csame++;

    }

    for (int i = 0; i < SIGMA; i++) {
        int l1 = at1;
        int l2 = at2;
        if (!done1) l1 = t1.st[l1].to[i];
        if (!done2) l2 = t2.st[l2].to[i];
        doit(t1, l1, done1 || l1 == 0, t2, l2, done2 || l2 == 0);
    }
}

int main() {

    int ts;
    scanf("%d\n", &ts);

    char *s1 = new char[MAXN];
    char *s2 = new char[MAXN];

    state *st1 = new state[MAXN];
    state *st2 = new state[MAXN];

    visited = new bool[MAXN];
    children = new vi[MAXN];

    for (int tz = 0; tz < ts; tz++) {
        scanf("%s\n", s1);
        scanf("%s\n", s2);

        int n1 = strlen(s1),
            n2 = strlen(s2);

        palindromic_tree t1(s1, st1);
        palindromic_tree t2(s2, st2);

        for (int i = 0; i < n1; i++) {
            t1.extend();
            t1.st[t1.last].cnt++;
        }

        for (int i = 0; i < n2; i++) {
            t2.extend();
            t2.st[t2.last].cnt++;
        }

        memset(visited, 0, t1.sz);
        for (int i = 0; i < t1.sz; i++) children[i].clear();
        for (int i = 0; i < t1.sz; i++) {
            if (t1.st[i].link == -1) continue;
            children[t1.st[i].link].push_back(i);
        }
        for (int i = 0; i < t1.sz; i++) cntz(t1, i);

        memset(visited, 0, t2.sz);
        for (int i = 0; i < t1.sz; i++) children[i].clear();
        for (int i = 0; i < t2.sz; i++) {
            if (t2.st[i].link == -1) continue;
            children[t2.st[i].link].push_back(i);
        }
        for (int i = 0; i < t2.sz; i++) cntz(t2, i);


        /*
        outp(t1, 0, "");
        outp(t1, 1, "");
        cout << endl;
        outp(t2, 0, "");
        outp(t2, 1, "");
        cout << endl;
        */

        cleft = 0;
        csame = 0;
        cright = 0;
        doit(t1, 0, false, t2, 0, false);
        doit(t1, 1, false, t2, 1, false);

        printf("Case #%d: %d %d %d\n", tz+1, cleft, csame, cright);

    }

    return 0;
}

