#include <iostream>
#include <complex>
#include <vector>

using namespace std;

typedef long long int Z;
typedef complex<Z> V;

int n;
V pos[100005];

const int N = 1 << 17;
vector<int> hull[2 * N];

bool ccw(V a, V b, V c) {
	return ((c - a) * conj(b - a)).imag() > 0;
}

void init(int v = 1, int a = 0, int b = N) {
	hull[v].clear();
	
	for(int i = a; i < b && i < n; ++i) {
		while(hull[v].size() >= 2 && !ccw(pos[hull[v][hull[v].size() - 2]], pos[i], pos[hull[v].back()])) {
			hull[v].pop_back();
		}
		hull[v].push_back(i);
	}
	
	if(v < N) {
		int m = (a + b) >> 1;
		init(2 * v, a, m);
		init(2 * v + 1, m, b);
	}
}

bool hits(V s, V d, vector<int>& h) {
//	cout << "Hits";
//	for(int x : h) cout << ' ' << x + 1;
	
	int a = 0;
	int b = h.size() - 1;
	while(a != b) {
		int m = (a + b + 1) / 2;
		bool before; // "d" < m
		if(m == 0) {
			before = false;
		} else {
			before = ccw(0, pos[h[m]] - pos[h[m - 1]], d);
		}
		if(before) {
			b = m - 1;
		} else {
			a = m;
		}
	}
	
//	cout << " (" << h[a] + 1 << ")";
//	cout << " : " << ccw(s, s + d, pos[h[a]]) << "\n";
	return ccw(s, s + d, pos[h[a]]);
}

V s, d;
int find(int v, int a, int b, int sz = N) {
	if(b <= 0 || a >= sz) return -1;
	if(hull[v].empty()) return -1;
	
	if(sz == 1) {
		if(hits(s, d, hull[v])) {
			return 0;
		} else {
			return -1;
		}
	}
	
	if(a <= 0 && b >= sz) {
		if(!hits(s, d, hull[v])) return -1;
	}
	
	int csz = sz >> 1;
	int asd = find(2 * v, a, b, csz);
	if(asd != -1) return asd;
	asd = find(2 * v + 1, a - csz, b - csz, csz);
	if(asd != -1) return asd + csz;
	return -1;
}

int main() {
	cin.sync_with_stdio(false);
	int Te;
	cin >> Te;
	
	for(int te = 0; te < Te; ++te) {
		cin >> n;
		for(int i = 0; i < n; ++i) {
			Z x, y;
			cin >> x >> y;
			pos[i] = V(x, y);
		}
	
		init();
		
		for(int i = 0; i < n - 1; ++i) {
//			cout << i + 1 << ":\n";
			if(i != 0) cout << ' ';
			s = pos[i];
			d = pos[i + 1] - pos[i];
			int x = find(1, i + 2, n, N);
			if(x == -1) {
				cout << 0;
			} else {
				cout << x;
			}
		}
		cout << "\n";
	}
	
	return 0;
}
